[![ci-badge][]][ci] [![license-badge][]][license] [![docs-badge][]][docs] [![rust badge]][rust link]

# urbandictionary.rs

Unofficial async Rust client for the Urbandictionary API.

[Documentation][docs]

### Installation

This library requires at least Rust 1.21.

Add the following dependency to your Cargo.toml:

```toml
urbandictionary = "0.3"
```

And include it in your project:

```rust
extern crate urbandictionary;
```

### Examples

Using `hyper` with the `hyper-tls` HTTPS connector, retrieve a list of
definitions for a word and print the example of the second definition if it
exists:

```rust
extern crate futures;
extern crate hyper;
extern crate hyper_tls;
extern crate tokio_core;
extern crate urbandictionary;

use futures::Future;
use hyper::client::{Client, HttpConnector};
use hyper_tls::HttpsConnector;
use std::error::Error;
use tokio_core::reactor::Core;
use urbandictionary::HyperUrbanDictionaryRequester;

fn try_main() -> Result<(), Box<Error>> {
    let mut core = Core::new()?;
    let client = Client::configure()
        .connector(HttpsConnector::new(4, &core.handle())?)
        .build(&core.handle());

    let done = client.definitions("cat").and_then(|response| {
        if let Some(definition) = response.definitions.get(1) {
            println!("Examples: {}", definition.example);
        }

        Ok(())
    }).map_err(|_| ());

    core.run(done).expect("Error running core");

    Ok(())
}

fn main() {
    try_main().unwrap();
}
```

Using reqwest, print the definition of the word `"cat"`:

```rust
extern crate reqwest;
extern crate urbandictionary;

use reqwest::Client;
use std::error::Error;
use urbandictionary::ReqwestUrbanDictionaryRequester;


fn try_main() -> Result<(), Box<Error>> {
    let client = Client::new();
    let response = client.define("cat")?;

    if let Some(definition) = response {
        println!("The definition of cat is: {}", definition.definition);
    } else {
        println!("No definition found");
    }

    Ok(())
}

fn main() {
    try_main().unwrap();
}
```

[ci-badge]: https://github.com/zeyla/urbandictionary.rs/workflows/Test/badge.svg
[ci]: https://github.com/zeyla/urbandictionary.rs/actions
[docs-badge]: https://img.shields.io/badge/docs-online-2020ff.svg?style=flat-square
[docs]: https://docs.rs/urbandictionary
[license-badge]: https://img.shields.io/badge/license-ISC-blue.svg?style=flat-square
[license]: https://opensource.org/licenses/ISC
[rust badge]: https://img.shields.io/badge/rust-1.39%20(beta)+-93450a.svg?style=flat-square
[rust link]: https://blog.rust-lang.org/2019/09/30/Async-await-hits-beta.html
