use reqwest::Error as ReqwestError;
use serde_json::Error as JsonError;
use snafu::Snafu;
use std::result::Result as StdResult;

/// Common result type used throughout the library.
pub type Result<T> = StdResult<T, Error>;

/// Common error type used throughout the library, to be used as a holder for
/// errors from various other libraries.
#[derive(Debug, Snafu)]
#[snafu(visibility(pub(crate)))]
pub enum Error {
    /// Chunking the response body as UTF-8 failed.
    ChunkingText { source: ReqwestError },
    /// Deserializing a JSON payload failed.
    Deserializing { source: JsonError, text: String },
    /// An error occurred while getting a response.
    Request { source: ReqwestError },
}

impl From<ReqwestError> for Error {
    fn from(source: ReqwestError) -> Self {
        Self::Request { source }
    }
}
