//! [![ci-badge][]][ci] [![license-badge][]][license] [![docs-badge][]][docs] [![rust badge]][rust link]
//!
//! # urbandictionary.rs
//!
//! Unofficial async Rust client for the Urbandictionary API.
//!
//! ### Installation
//!
//! Add the following dependency to your Cargo.toml:
//!
//! ```toml
//! urbandictionary = "0.4.0-alpha.0"
//! ```
//!
//! ### Examples
//!
//! Using `hyper` with the `hyper-tls` HTTPS connector, retrieve a list of
//! definitions for a word and print the example of the second definition if it
//! exists:
//!
//! ```no_run
//! use reqwest::Client as HttpClient;
//! use urbandictionary::Client;
//!
//! # #[tokio::main]
//! # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
//! let http_client = HttpClient::new();
//! let client = Client::new(http_client);
//!
//! let definition = client.define("cat").await?;
//!
//! if let Some(definition) = definition {
//!     println!("Examples: {}", definition.example);
//! }
//! # Ok(()) }
//! ```
//!
//! [ci-badge]: https://github.com/zeyla/top.gg.rs/workflows/Test/badge.svg
//! [ci]: https://github.com/zeyla/top.gg.rs/actions
//! [docs-badge]: https://img.shields.io/badge/docs-online-2020ff.svg?style=flat-square
//! [docs]: https://docs.rs/top-gg
//! [license-badge]: https://img.shields.io/badge/license-ISC-blue.svg?style=flat-square
//! [license]: https://opensource.org/licenses/ISC
//! [rust badge]: https://img.shields.io/badge/rust-1.39%20(beta)+-93450a.svg?style=flat-square
//! [rust link]: https://blog.rust-lang.org/2019/09/30/Async-await-hits-beta.html

pub mod error;
pub mod model;

mod client;

pub use client::Client;
